@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # vim: set ft=python ts=4 sw=4 expandtab:
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
@@ -47,7 +46,7 @@ Implements the standard 'collect' action.
 
 import logging
 import os
-import pickle
+import pickle  # noqa: S403 # we operate on trusted data, so pickle is ok
 
 from CedarBackup3.actions.constants import COLLECT_INDICATOR, DIGEST_EXTENSION
 from CedarBackup3.actions.util import writeIndicatorFile
@@ -70,8 +69,7 @@ logger = logging.getLogger("CedarBackup3.log.actions.collect")
 ############################
 
 
-# pylint: disable=W0613
-def executeCollect(configPath, options, config):
+def executeCollect(configPath, options, config):  # noqa: ARG001
     """
     Executes the collect backup action.
 
@@ -361,7 +359,7 @@ def _loadDigest(digestPath):
     else:
         try:
             with open(digestPath, "rb") as f:
-                digest = pickle.load(f, fix_imports=True)  # be compatible with Python 2
+                digest = pickle.load(f, fix_imports=True)  # noqa: S301 # this is trusted data, so pickle is ok
             logger.debug("Loaded digest [%s] from disk: %d entries.", digestPath, len(digest))
         except Exception as e:
             digest = {}
@@ -577,7 +575,7 @@ def _getTarfilePath(config, absolutePath, archiveMode):
     elif archiveMode == "tarbz2":
         extension = "tar.bz2"
     normalized = buildNormalizedPath(absolutePath)
-    filename = "%s.%s" % (normalized, extension)  # pylint: disable=possibly-used-before-assignment:
+    filename = "%s.%s" % (normalized, extension)
     tarfilePath = pathJoin(config.collect.targetDir, filename)
     logger.debug("Tarfile path is [%s]", tarfilePath)
     return tarfilePath
