@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # vim: set ft=python ts=4 sw=4 expandtab:
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
@@ -73,8 +72,7 @@ logger = logging.getLogger("CedarBackup3.log.actions.store")
 ##########################
 
 
-# pylint: disable=W0613
-def executeStore(configPath, options, config):
+def executeStore(configPath, options, config):  # noqa: ARG001
     """
     Executes the store backup action.
 
@@ -388,7 +386,7 @@ def _findCorrectDailyDir(options, config):
         if os.path.isdir(todayPath) and os.path.exists(todayStageInd):
             logger.info("Store process will use current day's stage directory [%s]", todayPath)
             return {todayPath: todayDate}
-        raise IOError("Unable to find staging directory to store (only tried today due to full option).")
+        raise OSError("Unable to find staging directory to store (only tried today due to full option).")
     else:
         if os.path.isdir(todayPath) and os.path.exists(todayStageInd) and not os.path.exists(todayStoreInd):
             logger.info("Store process will use current day's stage directory [%s]", todayPath)
@@ -403,4 +401,4 @@ def _findCorrectDailyDir(options, config):
             if config.store.warnMidnite:
                 logger.warning("Warning: store process crossed midnite boundary to find data.")
             return {tomorrowPath: tomorrowDate}
-        raise IOError("Unable to find unused staging directory to store (tried today, yesterday, tomorrow).")
+        raise OSError("Unable to find unused staging directory to store (tried today, yesterday, tomorrow).")
