@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # vim: set ft=python ts=4 sw=4 expandtab:
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
@@ -147,7 +146,7 @@ def createWriter(config):
     deviceType = _getDeviceType(config)
     mediaType = _getMediaType(config)
     if deviceMounted(devicePath):
-        raise IOError("Device [%s] is currently mounted." % (devicePath))
+        raise OSError("Device [%s] is currently mounted." % (devicePath))
     if deviceType == "cdwriter":
         return CdWriter(devicePath, deviceScsiId, driveSpeed, mediaType, noEject, refreshMediaDelay, ejectDelay)
     elif deviceType == "dvdwriter":
@@ -175,7 +174,7 @@ def writeIndicatorFile(targetDir, indicatorFile, backupUser, backupGroup):
     filename = pathJoin(targetDir, indicatorFile)
     logger.debug("Writing indicator file [%s].", filename)
     try:
-        with open(filename, "w") as f:  # pylint: disable=unspecified-encoding
+        with open(filename, "w") as f:
             f.write("")
         changeOwnership(filename, backupUser, backupGroup)
     except Exception as e:
