@@ -1,5 +1,5 @@
-# -*- coding: utf-8 -*-
 # vim: set ft=python ts=4 sw=4 expandtab:
+# ruff: noqa: F401  # ruff does not like the imports here, but I don't want to break the public interface
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 #              C E D A R
@@ -34,4 +34,4 @@ library interface.
 # Imported modules
 ########################################################################
 
-from CedarBackup3.writers.util import IsoImage  # pylint: disable=W0611
+from CedarBackup3.writers.util import IsoImage
