@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # vim: set ft=python ts=4 sw=4 expandtab:
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
@@ -84,7 +83,7 @@ SU_COMMAND = ["su"]
 ########################################################################
 
 
-class LocalPeer(object):
+class LocalPeer:
     ######################
     # Class documentation
     ######################
@@ -239,7 +238,7 @@ class LocalPeer(object):
             raise ValueError("Target directory is not a directory or does not exist on disk.")
         count = LocalPeer._copyLocalDir(self.collectDir, targetDir, ownership, permissions)
         if count == 0:
-            raise IOError("Did not copy any files from local peer.")
+            raise OSError("Did not copy any files from local peer.")
         return count
 
     def checkCollectIndicator(self, collectIndicator=None):
@@ -378,9 +377,9 @@ class LocalPeer(object):
             return
         if not overwrite:
             if os.path.exists(targetFile):
-                raise IOError("Target file [%s] already exists." % targetFile)
+                raise OSError("Target file [%s] already exists." % targetFile)
         if sourceFile is None:
-            with open(targetFile, "w") as f:  # pylint: disable=unspecified-encoding
+            with open(targetFile, "w") as f:
                 f.write("")
         else:
             if os.path.isfile(sourceFile) and not os.path.islink(sourceFile):
@@ -390,7 +389,7 @@ class LocalPeer(object):
                 raise ValueError("Source is not a regular file.")
         if ownership is not None:
             if sys.platform != "win32":
-                os.chown(targetFile, ownership[0], ownership[1])  # pylint: disable=no-member
+                os.chown(targetFile, ownership[0], ownership[1])
         if permissions is not None:
             os.chmod(targetFile, permissions)
 
@@ -400,7 +399,7 @@ class LocalPeer(object):
 ########################################################################
 
 
-class RemotePeer(object):
+class RemotePeer:
     ######################
     # Class documentation
     ######################
@@ -763,7 +762,7 @@ class RemotePeer(object):
             permissions,
         )
         if count == 0:
-            raise IOError("Did not copy any files from local peer.")
+            raise OSError("Did not copy any files from local peer.")
         return count
 
     def checkCollectIndicator(self, collectIndicator=None):
@@ -816,10 +815,7 @@ class RemotePeer(object):
                     targetFile,
                     overwrite=False,
                 )
-                if os.path.exists(targetFile):
-                    return True
-                else:
-                    return False
+                return os.path.exists(targetFile)
             except Exception as e:
                 logger.info("Failed looking for collect indicator: %s", e)
                 return False
@@ -860,7 +856,7 @@ class RemotePeer(object):
             targetFile = pathJoin(self.collectDir, stageIndicator)
         try:
             if not os.path.exists(sourceFile):
-                with open(sourceFile, "w") as f:  # pylint: disable=unspecified-encoding
+                with open(sourceFile, "w") as f:
                     f.write("")
             RemotePeer._pushLocalFile(
                 self.remoteUser, self.localUser, self.name, self._rcpCommand, self._rcpCommandList, sourceFile, targetFile
@@ -899,9 +895,9 @@ class RemotePeer(object):
         try:
             command = RemotePeer._buildCbackCommand(self.cbackCommand, action, fullBackup)
             self.executeRemoteCommand(command)
-        except IOError as e:
+        except OSError as e:
             logger.info(e)
-            raise IOError("Failed to execute action [%s] on managed client [%s]." % (action, self.name))
+            raise OSError("Failed to execute action [%s] on managed client [%s]." % (action, self.name))
 
     ##################
     # Private methods
@@ -986,30 +982,30 @@ class RemotePeer(object):
         if localUser is not None:
             try:
                 if not isRunningAsRoot():
-                    raise IOError("Only root can remote copy as another user.")
+                    raise OSError("Only root can remote copy as another user.")
             except AttributeError:
                 pass
             actualCommand = "%s %s@%s:%s/* %s" % (rcpCommand, remoteUser, remoteHost, sourceDir, targetDir)
             command = resolveCommand(SU_COMMAND)
             result = executeCommand(command, [localUser, "-c", actualCommand])[0]
             if result != 0:
-                raise IOError("Error (%d) copying files from remote host as local user [%s]." % (result, localUser))
+                raise OSError("Error (%d) copying files from remote host as local user [%s]." % (result, localUser))
         else:
             copySource = "%s@%s:%s/*" % (remoteUser, remoteHost, sourceDir)
             command = resolveCommand(rcpCommandList)
             result = executeCommand(command, [copySource, targetDir])[0]
             if result != 0:
-                raise IOError("Error (%d) copying files from remote host." % result)
+                raise OSError("Error (%d) copying files from remote host." % result)
         afterSet = RemotePeer._getDirContents(targetDir)
         if len(afterSet) == 0:
-            raise IOError("Did not copy any files from remote peer.")
+            raise OSError("Did not copy any files from remote peer.")
         differenceSet = afterSet.difference(beforeSet)  # files we added as part of copy
         if len(differenceSet) == 0:
-            raise IOError("Apparently did not copy any new files from remote peer.")
+            raise OSError("Apparently did not copy any new files from remote peer.")
         for targetFile in differenceSet:
             if ownership is not None:
                 if sys.platform != "win32":
-                    os.chown(targetFile, ownership[0], ownership[1])  # pylint: disable=no-member
+                    os.chown(targetFile, ownership[0], ownership[1])
             if permissions is not None:
                 os.chmod(targetFile, permissions)
         return len(differenceSet)
@@ -1067,29 +1063,29 @@ class RemotePeer(object):
         """
         if not overwrite:
             if os.path.exists(targetFile):
-                raise IOError("Target file [%s] already exists." % targetFile)
+                raise OSError("Target file [%s] already exists." % targetFile)
         if localUser is not None:
             try:
                 if not isRunningAsRoot():
-                    raise IOError("Only root can remote copy as another user.")
+                    raise OSError("Only root can remote copy as another user.")
             except AttributeError:
                 pass
             actualCommand = "%s %s@%s:%s %s" % (rcpCommand, remoteUser, remoteHost, sourceFile.replace(" ", "\\ "), targetFile)
             command = resolveCommand(SU_COMMAND)
             result = executeCommand(command, [localUser, "-c", actualCommand])[0]
             if result != 0:
-                raise IOError("Error (%d) copying [%s] from remote host as local user [%s]." % (result, sourceFile, localUser))
+                raise OSError("Error (%d) copying [%s] from remote host as local user [%s]." % (result, sourceFile, localUser))
         else:
             copySource = "%s@%s:%s" % (remoteUser, remoteHost, sourceFile.replace(" ", "\\ "))
             command = resolveCommand(rcpCommandList)
             result = executeCommand(command, [copySource, targetFile])[0]
             if result != 0:
-                raise IOError("Error (%d) copying [%s] from remote host." % (result, sourceFile))
+                raise OSError("Error (%d) copying [%s] from remote host." % (result, sourceFile))
         if not os.path.exists(targetFile):
-            raise IOError("Apparently unable to copy file from remote host.")
+            raise OSError("Apparently unable to copy file from remote host.")
         if ownership is not None:
             if sys.platform != "win32":
-                os.chown(targetFile, ownership[0], ownership[1])  # pylint: disable=no-member
+                os.chown(targetFile, ownership[0], ownership[1])
         if permissions is not None:
             os.chmod(targetFile, permissions)
 
@@ -1124,24 +1120,24 @@ class RemotePeer(object):
         """
         if not overwrite:
             if os.path.exists(targetFile):
-                raise IOError("Target file [%s] already exists." % targetFile)
+                raise OSError("Target file [%s] already exists." % targetFile)
         if localUser is not None:
             try:
                 if not isRunningAsRoot():
-                    raise IOError("Only root can remote copy as another user.")
+                    raise OSError("Only root can remote copy as another user.")
             except AttributeError:
                 pass
             actualCommand = '%s "%s" "%s@%s:%s"' % (rcpCommand, sourceFile, remoteUser, remoteHost, targetFile)
             command = resolveCommand(SU_COMMAND)
             result = executeCommand(command, [localUser, "-c", actualCommand])[0]
             if result != 0:
-                raise IOError("Error (%d) copying [%s] to remote host as local user [%s]." % (result, sourceFile, localUser))
+                raise OSError("Error (%d) copying [%s] to remote host as local user [%s]." % (result, sourceFile, localUser))
         else:
             copyTarget = "%s@%s:%s" % (remoteUser, remoteHost, targetFile.replace(" ", "\\ "))
             command = resolveCommand(rcpCommandList)
             result = executeCommand(command, [sourceFile.replace(" ", "\\ "), copyTarget])[0]
             if result != 0:
-                raise IOError("Error (%d) copying [%s] to remote host." % (result, sourceFile))
+                raise OSError("Error (%d) copying [%s] to remote host." % (result, sourceFile))
 
     @staticmethod
     def _executeRemoteCommand(remoteUser, localUser, remoteHost, rshCommand, rshCommandList, remoteCommand):
@@ -1162,18 +1158,18 @@ class RemotePeer(object):
         if localUser is not None:
             try:
                 if not isRunningAsRoot():
-                    raise IOError("Only root can remote shell as another user.")
+                    raise OSError("Only root can remote shell as another user.")
             except AttributeError:
                 pass
             command = resolveCommand(SU_COMMAND)
             result = executeCommand(command, [localUser, "-c", actualCommand])[0]
             if result != 0:
-                raise IOError('Command failed [su -c %s "%s"]' % (localUser, actualCommand))
+                raise OSError('Command failed [su -c %s "%s"]' % (localUser, actualCommand))
         else:
             command = resolveCommand(rshCommandList)
             result = executeCommand(command, ["%s@%s" % (remoteUser, remoteHost), "%s" % remoteCommand])[0]
             if result != 0:
-                raise IOError("Command failed [%s]" % (actualCommand))
+                raise OSError("Command failed [%s]" % (actualCommand))
 
     @staticmethod
     def _buildCbackCommand(cbackCommand, action, fullBackup):
