@@ -1,5 +1,5 @@
-# -*- coding: utf-8 -*-
 # vim: set ft=python ts=4 sw=4 expandtab:
+# ruff: noqa: PLC1901
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 #              C E D A R
@@ -280,8 +280,7 @@ class UnorderedList(list):
         else:
             typeinfo = type(value)
         try:
-            # pylint: disable=R0124
-            x = value < value
+            _ = value < value  # noqa: PLR0124
         except TypeError:
             value = repr(value)
         return repr(typeinfo), value
@@ -367,7 +366,7 @@ class ObjectTypeList(UnorderedList):
            objectType: Type that the list elements must match
            objectName: Short string containing the "name" of the type
         """
-        super(ObjectTypeList, self).__init__()
+        super().__init__()
         self.objectType = objectType
         self.objectName = objectName
 
@@ -437,7 +436,7 @@ class RestrictedContentList(UnorderedList):
            valuesDescr: Short string describing list of values
            prefix: Prefix to use in error messages (None results in prefix "Item")
         """
-        super(RestrictedContentList, self).__init__()
+        super().__init__()
         self.prefix = "Item"
         if prefix is not None:
             self.prefix = prefix
@@ -507,7 +506,7 @@ class RegexMatchList(UnorderedList):
            emptyAllowed: Indicates whether empty or None values are allowed
            prefix: Prefix to use in error messages (None results in prefix "Item")
         """
-        super(RegexMatchList, self).__init__()
+        super().__init__()
         self.prefix = "Item"
         if prefix is not None:
             self.prefix = prefix
@@ -621,7 +620,7 @@ class RegexList(UnorderedList):
 ########################################################################
 
 
-class _Vertex(object):
+class _Vertex:
     """
     Represents a vertex (or node) in a directed graph.
     """
@@ -639,7 +638,7 @@ class _Vertex(object):
 
 
 @total_ordering
-class DirectedGraph(object):
+class DirectedGraph:
     """
     Represents a directed graph.
 
@@ -710,7 +709,6 @@ class DirectedGraph(object):
         Returns:
             -1/0/1 depending on whether self is ``<``, ``=`` or ``>`` other
         """
-        # pylint: disable=W0212
         if other is None:
             return 1
         if self.name != other.name:
@@ -718,8 +716,8 @@ class DirectedGraph(object):
                 return -1
             else:
                 return 1
-        if self._vertices != other._vertices:
-            if self._vertices < other._vertices:
+        if self._vertices != other._vertices:  # noqa: SLF001
+            if self._vertices < other._vertices:  # noqa: SLF001
                 return -1
             else:
                 return 1
@@ -826,7 +824,7 @@ class DirectedGraph(object):
 ########################################################################
 
 
-class PathResolverSingleton(object):
+class PathResolverSingleton:
     """
     Singleton used for resolving executable paths.
 
@@ -883,8 +881,7 @@ class PathResolverSingleton(object):
         def __init__(self):
             pass
 
-        def __call__(self, *args, **kw):
-            # pylint: disable=W0212
+        def __call__(self, *args, **kw):  # noqa: ARG002
             if PathResolverSingleton._instance is None:
                 obj = PathResolverSingleton()
                 PathResolverSingleton._instance = obj
@@ -954,7 +951,7 @@ class Pipe(Popen):
 ########################################################################
 
 
-class Diagnostics(object):
+class Diagnostics:
     """
     Class holding runtime diagnostic information.
 
@@ -1046,8 +1043,7 @@ class Diagnostics(object):
         """
         tmax = 0
         for value in values:
-            if len(value) > tmax:
-                tmax = len(value)
+            tmax = max(tmax, len(value))
         return tmax
 
     def _getVersion(self):
@@ -1080,7 +1076,7 @@ class Diagnostics(object):
                 machine = platform.machine()
                 return "%s (%s %s)" % (sysname, release, machine)
             else:
-                uname = os.uname()  # pylint: disable=no-member
+                uname = os.uname()
                 sysname = uname[0]  # i.e. Linux
                 release = uname[2]  # i.e. 2.16.18-2
                 machine = uname[4]  # i.e. i686
@@ -1093,12 +1089,12 @@ class Diagnostics(object):
         Property target to get the default locale that is in effect.
         """
         try:
-            import locale  # pylint: disable=import-outside-toplevel
+            import locale  # noqa: PLC0415
 
             try:
                 return locale.getlocale()[0]  # python >= 3.11 deprecates getdefaultlocale() in favor of getlocale()
             except:
-                return locale.getdefaultlocale()[0]  # pylint: disable=deprecated-method:
+                return locale.getdefaultlocale()[0]
         except:
             return "(unknown)"
 
@@ -1107,13 +1103,13 @@ class Diagnostics(object):
         Property target to get a current date/time stamp.
         """
         try:
-            import datetime  # pylint: disable=import-outside-toplevel
+            import datetime  # noqa: PLC0415
 
             if list(map(int, [sys.version_info[0], sys.version_info[1]])) < [3, 12]:
                 # Starting with Python 3.12, utcnow() is deprecated
                 return datetime.datetime.utcnow().ctime() + " UTC"
             else:
-                return datetime.datetime.now(datetime.UTC).ctime() + " UTC"  # pylint: disable=no-member:
+                return datetime.datetime.now(datetime.UTC).ctime() + " UTC"
         except:
             return "(unknown)"
 
@@ -1143,7 +1139,7 @@ def sortDict(d):
         List of dictionary keys sorted in order by dictionary value
     """
     items = list(d.items())
-    items.sort(key=lambda x: (x[1], x[0]))  # sort by value and then by key
+    items.sort(key=lambda x: (x[1], x[0]))  # noqa: FURB118 # sort by value and then by key
     return [key for key, value in items]
 
 
@@ -1230,7 +1226,7 @@ def convertSize(size, fromUnit, toUnit):
 ##########################
 
 
-def displayBytes(bytes, digits=2):  # pylint: disable=W0622
+def displayBytes(bytes, digits=2):  # noqa: A002
     """
     Format a byte quantity so it can be sensibly displayed.
 
@@ -1259,7 +1255,7 @@ def displayBytes(bytes, digits=2):  # pylint: disable=W0622
     """
     if bytes is None:
         raise ValueError("Cannot display byte value of None.")
-    bytes = float(bytes)
+    bytes = float(bytes)  # noqa: A001
     if math.fabs(bytes) < BYTES_PER_KBYTE:
         fmt = "%.0f bytes"
         value = bytes
@@ -1395,7 +1391,7 @@ def changeOwnership(path, user, group):
         else:
             try:
                 (uid, gid) = getUidGid(user, group)
-                os.chown(path, uid, gid)  # pylint: disable=no-member
+                os.chown(path, uid, gid)
             except Exception as e:
                 logger.error("Error changing ownership of [%s]: %s", path, e)
 
@@ -1411,7 +1407,7 @@ def isRunningAsRoot():
     """
     if sys.platform == "win32":
         return False
-    return os.getuid() == 0  # pylint: disable=no-member
+    return os.getuid() == 0
 
 
 ##############################
@@ -1443,9 +1439,8 @@ def splitCommandLine(commandLine):
     """
     if commandLine is None:
         raise ValueError("Cannot split command line of None.")
-    fields = re.findall('[^ "]+|"[^"]+"', commandLine)
-    fields = [field.replace('"', "") for field in fields]
-    return fields
+    fields = re.findall(r'[^ "]+|"[^"]+"', commandLine)
+    return [field.replace('"', "") for field in fields]
 
 
 ############################
@@ -1647,8 +1642,7 @@ def calculateFileAge(path):
     fileStats = os.stat(path)
     lastUse = max(fileStats.st_atime, fileStats.st_mtime)  # "most recent" is "largest"
     ageInSeconds = currentTime - lastUse
-    ageInDays = ageInSeconds / SECONDS_PER_DAY
-    return ageInDays
+    return ageInSeconds / SECONDS_PER_DAY
 
 
 ###################
@@ -1685,7 +1679,7 @@ def mount(devicePath, mountPoint, fsType):
     command = resolveCommand(MOUNT_COMMAND)
     result = executeCommand(command, args, returnOutput=False, ignoreStderr=True)[0]
     if result != 0:
-        raise IOError("Error [%d] mounting [%s] at [%s] as [%s]." % (result, devicePath, mountPoint, fsType))
+        raise OSError("Error [%d] mounting [%s] at [%s] as [%s]." % (result, devicePath, mountPoint, fsType))
 
 
 #####################
@@ -1727,7 +1721,7 @@ def unmount(mountPoint, removeAfter=False, attempts=1, waitSeconds=0):
        IOError: If the mount point is still mounted after attempts are exhausted
     """
     if os.path.ismount(mountPoint):
-        for attempt in range(0, attempts):
+        for attempt in range(attempts):
             logger.debug("Making attempt %d to unmount [%s].", attempt, mountPoint)
             command = resolveCommand(UMOUNT_COMMAND)
             result = executeCommand(command, [mountPoint], returnOutput=False, ignoreStderr=True)[0]
@@ -1744,7 +1738,7 @@ def unmount(mountPoint, removeAfter=False, attempts=1, waitSeconds=0):
                     time.sleep(waitSeconds)
         else:
             if os.path.ismount(mountPoint):
-                raise IOError("Unable to unmount [%s] after %d attempts." % (mountPoint, attempts))
+                raise OSError("Unable to unmount [%s] after %d attempts." % (mountPoint, attempts))
             logger.info("Mount point [%s] seems to have finally gone away.", mountPoint)
         if os.path.isdir(mountPoint) and removeAfter:
             logger.debug("Removing mount point [%s].", mountPoint)
@@ -1776,10 +1770,10 @@ def deviceMounted(devicePath):
     """
     if os.path.exists(MTAB_FILE) and os.access(MTAB_FILE, os.R_OK):
         realPath = os.path.realpath(devicePath)
-        with open(MTAB_FILE) as f:  # pylint: disable=unspecified-encoding
+        with open(MTAB_FILE) as f:
             lines = f.readlines()
         for line in lines:
-            (mountDevice, mountPoint, remainder) = line.split(None, 2)
+            (mountDevice, mountPoint, _) = line.split(None, 2)
             if mountDevice in [devicePath, realPath]:
                 logger.debug("Device [%s] is mounted at [%s].", devicePath, mountPoint)
                 return True
@@ -1955,7 +1949,7 @@ def buildNormalizedPath(path):
         raise ValueError("Cannot normalize path None.")
     elif len(path) == 0:
         return path
-    elif path == "/" or path == "\\":
+    elif path in {"/", "\\"}:
         return "_"
     else:
         normalized = path
@@ -1966,8 +1960,7 @@ def buildNormalizedPath(path):
         normalized = re.sub(r"/", "-", normalized)  # convert all '/' characters to '-'
         normalized = re.sub(r"\\", "-", normalized)  # convert all '\' characters to '-'
         normalized = re.sub(r"\s", "_", normalized)  # convert all whitespace to '_'
-        normalized = re.sub(r":", "_", normalized)  # convert all remaining colons to '_'
-        return normalized
+        return re.sub(r":", "_", normalized)  # convert all remaining colons to '_'
 
 
 #################################
@@ -2079,7 +2072,7 @@ def parseCommaSeparatedString(commaString):
         pass1 = commaString.split(",")
         pass2 = []
         for item in pass1:
-            item = item.strip()
-            if len(item) > 0:
-                pass2.append(item)
+            stripped = item.strip()
+            if len(stripped) > 0:
+                pass2.append(stripped)
         return pass2
