@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # vim: set ft=python ts=4 sw=4 expandtab:
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
@@ -95,7 +94,7 @@ MKISOFS_COMMAND = ["mkisofs"]
 ########################################################################
 
 
-class MediaDefinition(object):
+class MediaDefinition:
     """
     Class encapsulating information about CD media definitions.
 
@@ -194,7 +193,7 @@ class MediaDefinition(object):
 ########################################################################
 
 
-class MediaCapacity(object):
+class MediaCapacity:
     """
     Class encapsulating information about CD media capacity.
 
@@ -276,7 +275,7 @@ class MediaCapacity(object):
 ########################################################################
 
 
-class _ImageProperties(object):
+class _ImageProperties:
     """
     Simple value object to hold image properties for ``DvdWriter``.
     """
@@ -293,7 +292,7 @@ class _ImageProperties(object):
 ########################################################################
 
 
-class CdWriter(object):
+class CdWriter:
     ######################
     # Class documentation
     ######################
@@ -608,7 +607,7 @@ class CdWriter(object):
         command = resolveCommand(CDRECORD_COMMAND)
         (result, output) = executeCommand(command, args, returnOutput=True, ignoreStderr=True)
         if result != 0:
-            raise IOError("Error (%d) executing cdrecord command to get properties." % result)
+            raise OSError("Error (%d) executing cdrecord command to get properties." % result)
         return CdWriter._parsePropertiesOutput(output)
 
     def retrieveCapacity(self, entireDisc=False, useMulti=True):
@@ -835,7 +834,7 @@ class CdWriter(object):
                     self.unlockTray()
                     result = executeCommand(EJECT_COMMAND, args)[0]
                     if result != 0:
-                        raise IOError(
+                        raise OSError(
                             "Error (%d) executing eject command to open tray (failed even after unlocking tray)." % result
                         )
                     logger.debug("Kludge was apparently successful.")
@@ -853,7 +852,7 @@ class CdWriter(object):
         command = resolveCommand(EJECT_COMMAND)
         result = executeCommand(command, args)[0]
         if result != 0:
-            raise IOError("Error (%d) executing eject command to unlock tray." % result)
+            raise OSError("Error (%d) executing eject command to unlock tray." % result)
 
     def closeTray(self):
         """
@@ -876,7 +875,7 @@ class CdWriter(object):
                 command = resolveCommand(EJECT_COMMAND)
                 result = executeCommand(command, args)[0]
                 if result != 0:
-                    raise IOError("Error (%d) executing eject command to close tray." % result)
+                    raise OSError("Error (%d) executing eject command to close tray." % result)
 
     def refreshMedia(self):
         """
@@ -977,7 +976,7 @@ class CdWriter(object):
         logger.debug("Media capacity: %s", displayBytes(available))
         if size > available:
             logger.error("Image [%s] does not fit in available capacity [%s].", displayBytes(size), displayBytes(available))
-            raise IOError("Media does not contain enough capacity to store image.")
+            raise OSError("Media does not contain enough capacity to store image.")
         try:
             (handle, path) = tempfile.mkstemp(dir=self._image.tmpdir)
             try:
@@ -1010,7 +1009,7 @@ class CdWriter(object):
         command = resolveCommand(CDRECORD_COMMAND)
         result = executeCommand(command, args)[0]
         if result != 0:
-            raise IOError("Error (%d) executing command to write disc." % result)
+            raise OSError("Error (%d) executing command to write disc." % result)
         self.refreshMedia()
 
     def _blankMedia(self):
@@ -1024,7 +1023,7 @@ class CdWriter(object):
             command = resolveCommand(CDRECORD_COMMAND)
             result = executeCommand(command, args)[0]
             if result != 0:
-                raise IOError("Error (%d) executing command to blank disc." % result)
+                raise OSError("Error (%d) executing command to blank disc." % result)
             self.refreshMedia()
 
     #######################################
@@ -1149,11 +1148,11 @@ class CdWriter(object):
         boundaryPattern = re.compile(r"(^\s*)([0-9]*)(\s*,\s*)([0-9]*)(\s*$)")
         parsed = boundaryPattern.search(output[0])
         if not parsed:
-            raise IOError("Unable to parse output of boundaries command.")
+            raise OSError("Unable to parse output of boundaries command.")
         try:
             boundaries = (int(parsed.group(2)), int(parsed.group(4)))
         except TypeError:
-            raise IOError("Unable to parse output of boundaries command.")
+            raise OSError("Unable to parse output of boundaries command.")
         return boundaries
 
     #################################
