@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # vim: set ft=python ts=4 sw=4 expandtab:
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
@@ -90,7 +89,7 @@ EJECT_COMMAND = ["eject"]
 ########################################################################
 
 
-class MediaDefinition(object):
+class MediaDefinition:
     """
     Class encapsulating information about DVD media definitions.
 
@@ -167,7 +166,7 @@ class MediaDefinition(object):
 ########################################################################
 
 
-class MediaCapacity(object):
+class MediaCapacity:
     """
     Class encapsulating information about DVD media capacity.
 
@@ -231,7 +230,7 @@ class MediaCapacity(object):
 ########################################################################
 
 
-class _ImageProperties(object):
+class _ImageProperties:
     """
     Simple value object to hold image properties for ``DvdWriter``.
     """
@@ -248,7 +247,7 @@ class _ImageProperties(object):
 ########################################################################
 
 
-class DvdWriter(object):
+class DvdWriter:
     ######################
     # Class documentation
     ######################
@@ -642,7 +641,7 @@ class DvdWriter(object):
                 self.unlockTray()
                 result = executeCommand(command, args)[0]
                 if result != 0:
-                    raise IOError("Error (%d) executing eject command to open tray (failed even after unlocking tray)." % result)
+                    raise OSError("Error (%d) executing eject command to open tray (failed even after unlocking tray)." % result)
                 logger.debug("Kludge was apparently successful.")
             if self.ejectDelay is not None:
                 logger.debug("Per configuration, sleeping %d seconds after opening tray.", self.ejectDelay)
@@ -658,7 +657,7 @@ class DvdWriter(object):
         args = ["-i", "off", self.device]
         result = executeCommand(command, args)[0]
         if result != 0:
-            raise IOError("Error (%d) executing eject command to unlock tray." % result)
+            raise OSError("Error (%d) executing eject command to unlock tray." % result)
 
     def closeTray(self):
         """
@@ -678,7 +677,7 @@ class DvdWriter(object):
             args = ["-t", self.device]
             result = executeCommand(command, args)[0]
             if result != 0:
-                raise IOError("Error (%d) executing eject command to close tray." % result)
+                raise OSError("Error (%d) executing eject command to close tray." % result)
 
     def refreshMedia(self):
         """
@@ -750,7 +749,7 @@ class DvdWriter(object):
             available = self.retrieveCapacity(entireDisc=self._image.newDisc).bytesAvailable
             if size > available:
                 logger.error("Image [%s] does not fit in available capacity [%s].", displayBytes(size), displayBytes(available))
-                raise IOError("Media does not contain enough capacity to store image.")
+                raise OSError("Media does not contain enough capacity to store image.")
             self._writeImage(self._image.newDisc, None, self._image.entries, self._image.mediaLabel)
         else:
             if not (os.path.isabs(imagePath) or posixpath.isabs(imagePath)):  # Python 3.13+ does not treat / as absolute on Windows
@@ -783,7 +782,7 @@ class DvdWriter(object):
         (result, output) = executeCommand(command, args, returnOutput=True)
         if result != 0:
             DvdWriter._searchForOverburn(output)  # throws own exception if overburn condition is found
-            raise IOError("Error (%d) executing command to write disc." % result)
+            raise OSError("Error (%d) executing command to write disc." % result)
         self.refreshMedia()
 
     @staticmethod
@@ -814,8 +813,7 @@ class DvdWriter(object):
         image = IsoImage()
         for path in list(entries.keys()):
             image.addEntry(path, entries[path], override=False, contentsOnly=True)
-        estimatedSize = image.getEstimatedSize() + fudgeFactor
-        return estimatedSize
+        return image.getEstimatedSize() + fudgeFactor
 
     def _retrieveSectorsUsed(self):
         """
@@ -922,7 +920,7 @@ class DvdWriter(object):
                     logger.error("Image [%s] does not fit in available capacity [%s].", displayBytes(size), displayBytes(available))
                 except ValueError:
                     logger.error("Image does not fit in available capacity (no useful capacity info available).")
-                raise IOError("Media does not contain enough capacity to store image.")
+                raise OSError("Media does not contain enough capacity to store image.")
 
     @staticmethod
     def _buildWriteArgs(newDisc, hardwareId, driveSpeed, imagePath, entries, mediaLabel=None, dryRun=False):
