@@ -1,5 +1,5 @@
-# -*- coding: utf-8 -*-
 # vim: set ft=python ts=4 sw=4 expandtab:
+# ruff: noqa: PLR6104
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
 #              C E D A R
@@ -56,7 +56,6 @@ Attributes:
 
 :author: Kenneth J. Pronovici <pronovic@ieee.org>
 """
-# pylint: disable=C0111,C0103,W0511,W0104,W0106
 
 ########################################################################
 # Imported modules
@@ -66,7 +65,7 @@ import logging
 import re
 import sys
 from io import StringIO
-from xml.dom.minidom import Node, getDOMImplementation, parseString
+from xml.dom.minidom import Node, getDOMImplementation, parseString  # noqa: S408 # we assume trusted data, so xml.dom is ok
 from xml.parsers.expat import ExpatError
 
 ########################################################################
@@ -94,10 +93,10 @@ def createInputDom(xmlData, name="cb_config"):
        ValueError: If the document can't be parsed
     """
     try:
-        xmlDom = parseString(xmlData)
+        xmlDom = parseString(xmlData)  # noqa: S318 # we assume trusted data, so xml.dom is ok
         parentNode = readFirstChild(xmlDom, name)
         return (xmlDom, parentNode)
-    except (IOError, ExpatError) as e:
+    except (OSError, ExpatError) as e:
         raise ValueError("Unable to parse XML document: %s" % e)
 
 
@@ -485,7 +484,7 @@ def serializeDom(xmlDom, indent=3):
     return xmlData
 
 
-class Serializer(object):
+class Serializer:
     """
     XML serializer class.
 
@@ -541,12 +540,10 @@ class Serializer(object):
     def _write(self, text):
         obj = _encodeText(text, self.encoding)
         self.stream.write(obj)
-        return
 
     def _tryIndent(self):
         if not self._inText and self._indent:
             self._write("\n" + self._indent * self._depth)
-        return
 
     def _visit(self, node):
         """
@@ -595,12 +592,10 @@ class Serializer(object):
     def _visitNodeList(self, node, exclude=None):
         for curr in node:
             curr is not exclude and self._visit(curr)
-        return
 
     def _visitNamedNodeMap(self, node):
         for item in list(node.values()):
             self._visit(item)
-        return
 
     def _visitAttr(self, node):
         self._write(" " + node.name)
@@ -608,22 +603,18 @@ class Serializer(object):
         text = _translateCDATA(value, self.encoding)
         text, delimiter = _translateCDATAAttr(text)
         self.stream.write("=%s%s%s" % (delimiter, text, delimiter))
-        return
 
     def _visitProlog(self):
         self._write("<?xml version='1.0' encoding='%s'?>" % (self.encoding or "utf-8"))
         self._inText = 0
-        return
 
     def _visitDocument(self, node):
         self._visitProlog()
         node.doctype and self._visitDocumentType(node.doctype)
         self._visitNodeList(node.childNodes, exclude=node.doctype)
-        return
 
     def _visitDocumentFragment(self, node):
         self._visitNodeList(node.childNodes)
-        return
 
     def _visitElement(self, node):
         self._tryIndent()
@@ -640,7 +631,6 @@ class Serializer(object):
         else:
             self._write("/>")
         self._inText = 0
-        return
 
     def _visitText(self, node):
         text = node.data
@@ -650,7 +640,6 @@ class Serializer(object):
             text = _translateCDATA(text, self.encoding)
             self.stream.write(text)
             self._inText = 1
-        return
 
     def _visitDocumentType(self, doctype):
         if not doctype.systemId and not doctype.publicId:
@@ -693,7 +682,6 @@ class Serializer(object):
         node.systemId and self._write(" SYSTEM %s" % node.systemId)
         node.notationName and self._write(" NDATA %s" % node.notationName)
         self._write(">")
-        return
 
     def _visitNotation(self, node):
         """Visited from a NamedNodeMap in DocumentType"""
@@ -702,34 +690,28 @@ class Serializer(object):
         node.publicId and self._write(" PUBLIC %s" % node.publicId)
         node.systemId and self._write(" SYSTEM %s" % node.systemId)
         self._write(">")
-        return
 
     def _visitCDATASection(self, node):
         self._tryIndent()
         self._write("<![CDATA[%s]]>" % (node.data))
         self._inText = 0
-        return
 
     def _visitComment(self, node):
         self._tryIndent()
         self._write("<!--%s-->" % (node.data))
         self._inText = 0
-        return
 
     def _visitEntityReference(self, node):
         self._write("&%s;" % node.nodeName)
         self._inText = 1
-        return
 
     def _visitProcessingInstruction(self, node):
         self._tryIndent()
         self._write("<?%s %s?>" % (node.target, node.data))
         self._inText = 0
-        return
 
 
-# pylint: disable=W0613
-def _encodeText(text, encoding):
+def _encodeText(text, encoding):  # noqa: ARG001
     """Safely encodes the passed-in text as a Unicode string, converting bytes to UTF-8 if necessary."""
     if text is None:
         return text
@@ -754,15 +736,15 @@ def _translateCDATAAttr(characters):
         return "", "'"
     if "'" in characters:
         delimiter = '"'
-        new_chars = re.sub('"', "&quot;", characters)
+        new_chars = re.sub(r'"', "&quot;", characters)
     else:
         delimiter = "'"
-        new_chars = re.sub("'", "&apos;", characters)
+        new_chars = re.sub(r"'", "&apos;", characters)
     # FIXME: There's more to normalization
     # Convert attribute new-lines to character entity
     # characters is possibly shorter than new_chars (no entities)
     if "\n" in characters:
-        new_chars = re.sub("\n", "&#10;", new_chars)
+        new_chars = re.sub("\n", "&#10;", new_chars)  # noqa: RUF039
     return new_chars, delimiter
 
 
@@ -774,10 +756,10 @@ def _translateCDATA(characters, encoding="UTF-8", prev_chars="", markupSafe=0):
     Fourthought, Inc.  It its original form, it was Copyright (c) 2000
     Fourthought Inc, USA; All Rights Reserved.
     """
-    CDATA_CHAR_PATTERN = re.compile("[&<]|]]>")
+    CDATA_CHAR_PATTERN = re.compile(r"[&<]|]]>")
     CHAR_TO_ENTITY = {"&": "&amp;", "<": "&lt;", "]]>": "]]&gt;"}
-    ILLEGAL_LOW_CHARS = "[\x01-\x08\x0B-\x0C\x0E-\x1F]"
-    ILLEGAL_HIGH_CHARS = "\xEF\xBF[\xBE\xBF]"
+    ILLEGAL_LOW_CHARS = "[\x01-\x08\x0b-\x0c\x0e-\x1f]"
+    ILLEGAL_HIGH_CHARS = "\xef\xbf[\xbe\xbf]"
     XML_ILLEGAL_CHAR_PATTERN = re.compile("%s|%s" % (ILLEGAL_LOW_CHARS, ILLEGAL_HIGH_CHARS))
     if not characters:
         return ""
@@ -795,5 +777,4 @@ def _translateCDATA(characters, encoding="UTF-8", prev_chars="", markupSafe=0):
     # The UTF-8 for 0xFFFE and put out &#xFFFE;
     if XML_ILLEGAL_CHAR_PATTERN.search(new_string):
         new_string = XML_ILLEGAL_CHAR_PATTERN.subn(lambda m: "&#%i;" % ord(m.group()), new_string)[0]
-    new_string = _encodeText(new_string, encoding)
-    return new_string
+    return _encodeText(new_string, encoding)
