@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # vim: set ft=python ts=4 sw=4 expandtab:
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
 #
@@ -420,9 +419,9 @@ class TestIsoImage(unittest.TestCase):
             mountPath,
             imagePath,
         ]
-        (result, output) = executeCommand(HDIUTIL_CMD, args, returnOutput=True)
+        (result, _) = executeCommand(HDIUTIL_CMD, args, returnOutput=True)
         if result != 0:
-            raise IOError("Error (%d) executing command to mount image." % result)
+            raise OSError("Error (%d) executing command to mount image." % result)
         self.mounted = True
         return mountPath
 
@@ -454,9 +453,9 @@ class TestIsoImage(unittest.TestCase):
             imagePath,
             mountPath,
         ]
-        (result, output) = executeCommand(SUDO_CMD, args, returnOutput=True)
+        (result, _) = executeCommand(SUDO_CMD, args, returnOutput=True)
         if result != 0:
-            raise IOError("Error (%d) executing command to mount image." % result)
+            raise OSError("Error (%d) executing command to mount image." % result)
         self.mounted = True
         return mountPath
 
@@ -496,9 +495,9 @@ class TestIsoImage(unittest.TestCase):
             "detach",
             mountPath,
         ]
-        (result, output) = executeCommand(HDIUTIL_CMD, args, returnOutput=True)
+        (result, _) = executeCommand(HDIUTIL_CMD, args, returnOutput=True)
         if result != 0:
-            raise IOError("Error (%d) executing command to unmount image." % result)
+            raise OSError("Error (%d) executing command to unmount image." % result)
         self.mounted = False
 
     def unmountImageGeneric(self):
@@ -530,12 +529,12 @@ class TestIsoImage(unittest.TestCase):
             "iso9660",
             mountPath,
         ]
-        (result, output) = executeCommand(SUDO_CMD, args, returnOutput=True)
+        (result, _) = executeCommand(SUDO_CMD, args, returnOutput=True)
         if result != 0:
             time.sleep(1)
-            (result, output) = executeCommand(SUDO_CMD, args, returnOutput=True)
+            (result, _) = executeCommand(SUDO_CMD, args, returnOutput=True)
             if result != 0:
-                raise IOError("Error (%d) executing command to unmount image." % result)
+                raise OSError("Error (%d) executing command to unmount image." % result)
         self.mounted = False
 
     def disableGnomeAutomount(self):
@@ -560,7 +559,7 @@ class TestIsoImage(unittest.TestCase):
             ]
             (result, output) = executeCommand(GCONF_CMD, args, returnOutput=True)
             if result == 0:
-                self.origMediaAutomount = output[0][:-1]  # pylint: disable=W0201
+                self.origMediaAutomount = output[0][:-1]
                 if self.origMediaAutomount == "true":
                     args = [
                         "--type",
@@ -576,7 +575,7 @@ class TestIsoImage(unittest.TestCase):
             ]
             (result, output) = executeCommand(GCONF_CMD, args, returnOutput=True)
             if result == 0:
-                self.origMediaAutomountOpen = output[0][:-1]  # pylint: disable=W0201
+                self.origMediaAutomountOpen = output[0][:-1]
                 if self.origMediaAutomountOpen == "true":
                     args = [
                         "--type",
